@@ -3,6 +3,8 @@ import socket
 from dataclasses import dataclass
 import traceback
 import requests
+from IPython import get_ipython
+from IPython.core.ultratb import AutoFormattedTB
 
 from streaminglogs import StreamingLogsServiceContext, ActivityLog, ExceptionLog
 
@@ -16,11 +18,23 @@ class LoggingHandler:
     __ip_address: str
 
     @classmethod
-    def __init__(cls, context: StreamingLogsServiceContext, is_debug):
+    def __init__(cls, context: StreamingLogsServiceContext, is_debug, enable_unhandled_exceptions_tracing=False):
         cls.__context = context
         cls.__is_debug = is_debug
         cls.__origin = cls.__context.origin + '.debug' if cls.__is_debug else cls.__context.origin
         cls.__ip_address = cls.__get_ip()
+        if enable_unhandled_exceptions_tracing:
+            get_ipython().set_custom_exc((Exception,), cls.trace_unhandled_exception)
+
+    @classmethod
+    def trace_unhandled_exception(cls, shell, etype, evalue, tb, tb_offset=None):
+        shell.showtraceback((etype, evalue, tb), tb_offset=tb_offset)
+
+        itb = AutoFormattedTB(mode='Plain', tb_offset=1)
+        stb = itb.structured_traceback(etype, evalue, tb)
+        sstb = itb.stb2text(stb)
+
+        cls.trace_exception(Exception(sstb))
 
     @classmethod
     def trace_activity(cls, message: str, tags=None, console_only: bool = False):
@@ -78,6 +92,7 @@ class LoggingHandler:
     @staticmethod
     def __get_ip():
         return '0.0.0.0'
+        # This cause problems on some environments like for example Airflow
         s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
         try:
             # doesn't even have to be reachable
